==> zio-aws-qldb_2.13-5.17.191.2-sources.jar: zio/aws/qldb/model/package.scala <==
package zio.aws.qldb
import zio.aws.qldb.model.primitives.S3Bucket.Type
import java.time.Instant
import zio.aws.qldb.model.primitives.{TagValue, TagKey}
import zio.Chunk
import zio.prelude.Subtype
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.qldb.model.primitives.Arn.Type
    object DeletionProtection extends Subtype[Boolean]
    type DeletionProtection =
      zio.aws.qldb.model.primitives.DeletionProtection.Type
    object Digest extends Subtype[Chunk[Byte]]
    type Digest = zio.aws.qldb.model.primitives.Digest.Type
    object IonText extends Subtype[String]
    type IonText = zio.aws.qldb.model.primitives.IonText.Type
    object KmsKey extends Subtype[String]
    type KmsKey = zio.aws.qldb.model.primitives.KmsKey.Type
    object LedgerName extends Subtype[String]
    type LedgerName = zio.aws.qldb.model.primitives.LedgerName.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.qldb.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.qldb.model.primitives.NextToken.Type
    object S3Bucket extends Subtype[String]
    type S3Bucket = zio.aws.qldb.model.primitives.S3Bucket.Type
    object S3Prefix extends Subtype[String]
    type S3Prefix = zio.aws.qldb.model.primitives.S3Prefix.Type
    object StreamName extends Subtype[String]
    type StreamName = zio.aws.qldb.model.primitives.StreamName.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.qldb.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.qldb.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.qldb.model.primitives.Timestamp.Type
    object UniqueId extends Subtype[String]
    type UniqueId = zio.aws.qldb.model.primitives.UniqueId.Type
  }
  type JournalKinesisStreamDescriptionList =
    List[zio.aws.qldb.model.JournalKinesisStreamDescription]
  type JournalS3ExportList = List[zio.aws.qldb.model.JournalS3ExportDescription]
  type LedgerList = List[zio.aws.qldb.model.LedgerSummary]
  type TagKeyList = List[TagKey]
  type Tags = Map[TagKey, TagValue]
}

==> zio-aws-qldb_3-7.21.15.9-sources.jar: zio/aws/qldb/model/package.scala <==
package zio.aws.qldb
import zio.aws.qldb.model.primitives.S3Bucket.Type
import java.time.Instant
import zio.aws.qldb.model.primitives.{TagValue, TagKey}
import zio.Chunk
import zio.prelude.Subtype
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.qldb.model.primitives.Arn.Type
    object DeletionProtection extends Subtype[Boolean]
    type DeletionProtection =
      zio.aws.qldb.model.primitives.DeletionProtection.Type
    object Digest extends Subtype[Chunk[Byte]]
    type Digest = zio.aws.qldb.model.primitives.Digest.Type
    object IonText extends Subtype[String]
    type IonText = zio.aws.qldb.model.primitives.IonText.Type
    object KmsKey extends Subtype[String]
    type KmsKey = zio.aws.qldb.model.primitives.KmsKey.Type
    object LedgerName extends Subtype[String]
    type LedgerName = zio.aws.qldb.model.primitives.LedgerName.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.qldb.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.qldb.model.primitives.NextToken.Type
    object S3Bucket extends Subtype[String]
    type S3Bucket = zio.aws.qldb.model.primitives.S3Bucket.Type
    object S3Prefix extends Subtype[String]
    type S3Prefix = zio.aws.qldb.model.primitives.S3Prefix.Type
    object StreamName extends Subtype[String]
    type StreamName = zio.aws.qldb.model.primitives.StreamName.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.qldb.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.qldb.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.qldb.model.primitives.Timestamp.Type
    object UniqueId extends Subtype[String]
    type UniqueId = zio.aws.qldb.model.primitives.UniqueId.Type
  }
  type JournalKinesisStreamDescriptionList =
    List[zio.aws.qldb.model.JournalKinesisStreamDescription]
  type JournalS3ExportList = List[zio.aws.qldb.model.JournalS3ExportDescription]
  type LedgerList = List[zio.aws.qldb.model.LedgerSummary]
  type TagKeyList = List[TagKey]
  type Tags = Map[TagKey, TagValue]
}
